# Source: https://github.com/nickpmulder/ssd1306big
# Modified March 2025 by PostalPortal to remove things that aren't needed
#
# This is a driver for ssd1306 i2c oled displays using micropython. 
# This was written for a Raspberry Pi Pico but should work on any microcontroller running micropython. 
# It was based originally on the ssd1306.py module, but a new, larger font was drawn using framebuffer lines by Nick Mulder 
# This module is open source, and can be used for free for any purpose. 
# The default wiring is SDA to GP8 and SCL to GP9 for Rasberry Pi Pico


# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

oled = False

#The Alphabet
def A(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+5,(p.y)+1,1)
    oled.line((p.x)+5,(p.y)+1,(p.x)+10,(p.y)+15,1)
    oled.line((p.x)+3,(p.y)+11,(p.x)+8,(p.y)+11,1)    

def B(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+6,(p.y)+1,1)
    oled.line((p.x)+6,(p.y)+1,(p.x)+8,(p.y)+3,1)
    oled.line((p.x)+8,(p.y)+3,(p.x)+8,(p.y)+4,1)
    oled.line((p.x)+8,(p.y)+4,(p.x)+6,(p.y)+7,1)
    oled.line((p.x)+5,(p.y)+7,(p.x)+1,(p.y)+7,1)
    oled.line((p.x)+6,(p.y)+7,(p.x)+9,(p.y)+10,1)
    oled.line((p.x)+9,(p.y)+10,(p.x)+9,(p.y)+12,1)
    oled.line((p.x)+9,(p.y)+12,(p.x)+6,(p.y)+15,1)
    oled.line((p.x)+6,(p.y)+15,(p.x)+1,(p.y)+15,1)

def C(p):
    oled.line((p.x)+10,(p.y)+2,(p.x)+9,(p.y)+1,1)
    oled.line((p.x)+9,(p.y)+1,(p.x)+4,(p.y)+1,1)
    oled.line((p.x)+4,(p.y)+1,(p.x)+2,(p.y)+3,1)
    oled.line((p.x)+2,(p.y)+3,(p.x)+1,(p.y)+7,1)
    oled.line((p.x)+1,(p.y)+7,(p.x)+1,(p.y)+12,1)
    oled.line((p.x)+1,(p.y)+12,(p.x)+4,(p.y)+15,1)
    oled.line((p.x)+4,(p.y)+15,(p.x)+8,(p.y)+15,1)
    oled.line((p.x)+8,(p.y)+15,(p.x)+10,(p.y)+13,1)

def D(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+6,(p.y)+1,1)
    oled.line((p.x)+6,(p.y)+1,(p.x)+9,(p.y)+3,1)
    oled.line((p.x)+9,(p.y)+3,(p.x)+9,(p.y)+12,1)
    oled.line((p.x)+9,(p.y)+12,(p.x)+6,(p.y)+15,1)
    oled.line((p.x)+6,(p.y)+15,(p.x)+1,(p.y)+15,1)

def E(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+9,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+7,(p.x)+7,(p.y)+7,1)
    oled.line((p.x)+1,(p.y)+15,(p.x)+9,(p.y)+15,1)

def F(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+9,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+7,(p.x)+6,(p.y)+7,1)

def G(p):
    oled.line((p.x)+9,(p.y)+2,(p.x)+8,(p.y)+1,1)
    oled.line((p.x)+8,(p.y)+1,(p.x)+4,(p.y)+1,1)
    oled.line((p.x)+4,(p.y)+1,(p.x)+2,(p.y)+3,1)
    oled.line((p.x)+2,(p.y)+3,(p.x)+1,(p.y)+7,1)
    oled.line((p.x)+1,(p.y)+7,(p.x)+1,(p.y)+12,1)
    oled.line((p.x)+1,(p.y)+12,(p.x)+4,(p.y)+15,1)
    oled.line((p.x)+4,(p.y)+15,(p.x)+8,(p.y)+15,1)
    oled.line((p.x)+8,(p.y)+15,(p.x)+10,(p.y)+13,1)
    oled.line((p.x)+10,(p.y)+13,(p.x)+10,(p.y)+9,1)
    oled.line((p.x)+10,(p.y)+9,(p.x)+6,(p.y)+9,1)

def H(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+7,(p.x)+9,(p.y)+7,1)
    oled.line((p.x)+9,(p.y)+15,(p.x)+9,(p.y)+1,1)
    

def I(p):
    oled.line((p.x)+1,(p.y)+1,(p.x)+9,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+15,(p.x)+9,(p.y)+15,1)
    oled.line((p.x)+5,(p.y)+15,(p.x)+5,(p.y)+1,1)    

def J(p):
    oled.line((p.x)+9,(p.y)+1,(p.x)+9,(p.y)+10,1)
    oled.line((p.x)+9,(p.y)+10,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+3,(p.y)+15,1)
    oled.line((p.x)+3,(p.y)+15,(p.x)+1,(p.y)+10,1)

def K(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+9,(p.x)+8,(p.y)+1,1)
    oled.line((p.x)+4,(p.y)+7,(p.x)+9,(p.y)+15,1)
    
def L(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+15,(p.x)+9,(p.y)+15,1)

def M(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+5,(p.y)+7,1)
    oled.line((p.x)+9,(p.y)+1,(p.x)+5,(p.y)+7,1)
    oled.line((p.x)+9,(p.y)+15,(p.x)+9,(p.y)+1,1)

def N(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+9,(p.y)+15,1)
    oled.line((p.x)+9,(p.y)+15,(p.x)+9,(p.y)+1,1)

def O(p):
    oled.line((p.x)+10,(p.y)+5,(p.x)+8,(p.y)+1,1)
    oled.line((p.x)+8,(p.y)+1,(p.x)+4,(p.y)+1,1)
    oled.line((p.x)+4,(p.y)+1,(p.x)+2,(p.y)+3,1)
    oled.line((p.x)+2,(p.y)+3,(p.x)+1,(p.y)+7,1)
    oled.line((p.x)+1,(p.y)+7,(p.x)+1,(p.y)+12,1)
    oled.line((p.x)+1,(p.y)+12,(p.x)+4,(p.y)+15,1)
    oled.line((p.x)+4,(p.y)+15,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+10,(p.y)+12,1)
    oled.line((p.x)+10,(p.y)+12,(p.x)+10,(p.y)+5,1)

def P(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+7,(p.y)+1,1)
    oled.line((p.x)+7,(p.y)+1,(p.x)+9,(p.y)+4,1)
    oled.line((p.x)+9,(p.y)+4,(p.x)+9,(p.y)+6,1)
    oled.line((p.x)+9,(p.y)+6, (p.x)+6,(p.y)+9,1)
    oled.line((p.x)+5,(p.y)+9,(p.x)+1,(p.y)+9,1)

def Q(p):
    oled.line((p.x)+10,(p.y)+5,(p.x)+8,(p.y)+1,1)
    oled.line((p.x)+8,(p.y)+1,(p.x)+4,(p.y)+1,1)
    oled.line((p.x)+4,(p.y)+1,(p.x)+2,(p.y)+3,1)
    oled.line((p.x)+2,(p.y)+3,(p.x)+1,(p.y)+7,1)
    oled.line((p.x)+1,(p.y)+7,(p.x)+1,(p.y)+12,1)
    oled.line((p.x)+1,(p.y)+12,(p.x)+4,(p.y)+15,1)
    oled.line((p.x)+4,(p.y)+15,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+10,(p.y)+12,1)
    oled.line((p.x)+10,(p.y)+12,(p.x)+10,(p.y)+5,1)
    oled.line((p.x)+6,(p.y)+10,(p.x)+10,(p.y)+15,1)

def R(p):
    oled.line((p.x)+1,(p.y)+15,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+7,(p.y)+1,1)
    oled.line((p.x)+7,(p.y)+1,(p.x)+9,(p.y)+4,1)
    oled.line((p.x)+9,(p.y)+4,(p.x)+9,(p.y)+6,1)
    oled.line((p.x)+9,(p.y)+6, (p.x)+6,(p.y)+9,1)
    oled.line((p.x)+5,(p.y)+9,(p.x)+1,(p.y)+9,1)
    oled.line((p.x)+5,(p.y)+9,(p.x)+9,(p.y)+15,1)

def S(p):
    oled.line((p.x)+9,(p.y)+2,(p.x)+7,(p.y)+1,1)
    oled.line((p.x)+7,(p.y)+1,(p.x)+3,(p.y)+1,1)
    oled.line((p.x)+3,(p.y)+1,(p.x)+2,(p.y)+2,1)
    oled.line((p.x)+3,(p.y)+1,(p.x)+2,(p.y)+2,1)
    oled.line((p.x)+2,(p.y)+2,(p.x)+1,(p.y)+5,1)
    oled.line((p.x)+1,(p.y)+5,(p.x)+5,(p.y)+7,1)
    oled.line((p.x)+5,(p.y)+7,(p.x)+9,(p.y)+8,1)
    oled.line((p.x)+9,(p.y)+8,(p.x)+10,(p.y)+11,1)
    oled.line((p.x)+10,(p.y)+11,(p.x)+10,(p.y)+13,1)
    oled.line((p.x)+10,(p.y)+13,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+4,(p.y)+15,1)
    oled.line((p.x)+4,(p.y)+15,(p.x)+1,(p.y)+13,1)
    #oled.line((p.x)+10,(p.y)+13,(p.x)+7,(p.y)+15,1)

def T(p):
    oled.line((p.x)+5,(p.y)+15,(p.x)+5,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+9,(p.y)+1,1)

def U(p):
    oled.line((p.x)+1,(p.y)+1,(p.x)+1,(p.y)+13,1)
    oled.line((p.x)+1,(p.y)+13,(p.x)+3,(p.y)+15,1)
    oled.line((p.x)+3,(p.y)+15,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+9,(p.y)+13,1)
    oled.line((p.x)+9,(p.y)+13,(p.x)+9,(p.y)+1,1)

def V(p):
    oled.line((p.x)+1,(p.y)+1,(p.x)+5,(p.y)+15,1)
    oled.line((p.x)+5,(p.y)+15,(p.x)+9,(p.y)+1,1)

def W(p):
    oled.line((p.x)+1,(p.y)+1,(p.x)+3,(p.y)+15,1)
    oled.line((p.x)+3,(p.y)+15,(p.x)+5,(p.y)+8,1)
    oled.line((p.x)+5,(p.y)+8,(p.x)+8,(p.y)+15,1)
    oled.line((p.x)+8,(p.y)+15,(p.x)+10,(p.y)+1,1)

def X(p):
    oled.line((p.x)+1,(p.y)+1,(p.x)+9,(p.y)+15,1)
    oled.line((p.x)+9,(p.y)+1,(p.x)+1,(p.y)+15,1)

def Y(p):
    oled.line((p.x)+5,(p.y)+15,(p.x)+5,(p.y)+7,1)
    oled.line((p.x)+5,(p.y)+7,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+5,(p.y)+7,(p.x)+10,(p.y)+1,1)

def Z(p):
    oled.line((p.x)+1,(p.y)+1,(p.x)+9,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+15,(p.x)+9,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+15,(p.x)+9,(p.y)+15,1)

def period(p):
    oled.line((p.x)+1,(p.y)+14,(p.x)+2,(p.y)+14,1)
    oled.line((p.x)+1,(p.y)+15,(p.x)+2,(p.y)+15,1)

def exclam(p):
    oled.line((p.x)+1,(p.y)+14,(p.x)+1,(p.y)+15,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+1,(p.y)+10,1)

def plus(p):
    oled.line((p.x)+5,(p.y)+5,(p.x)+5,(p.y)+11,1)
    oled.line((p.x)+2,(p.y)+8,(p.x)+8,(p.y)+8,1)

def minus(p):
    oled.line((p.x)+2,(p.y)+8,(p.x)+8,(p.y)+8,1)

def equal(p):
    oled.line((p.x)+2,(p.y)+6,(p.x)+8,(p.y)+6,1)
    oled.line((p.x)+2,(p.y)+9,(p.x)+8,(p.y)+9,1)

def comma(p):
    oled.line((p.x)+1,(p.y)+13,(p.x)+1,(p.y)+14,1)
    oled.line((p.x)+2,(p.y)+13,(p.x)+2,(p.y)+17,1)
    oled.line((p.x)+1,(p.y)+17,(p.x)+2,(p.y)+17,1)

def colon(p):
    oled.line((p.x)+1,(p.y)+14,(p.x)+2,(p.y)+14,1)
    oled.line((p.x)+1,(p.y)+15,(p.x)+2,(p.y)+15,1)
    oled.line((p.x)+1,(p.y)+6,(p.x)+2,(p.y)+6,1)
    oled.line((p.x)+1,(p.y)+5,(p.x)+2,(p.y)+5,1)

def slash(p):
    oled.line((p.x)+9,(p.y)+1,(p.x)+1,(p.y)+15,1)

def question(p):
    oled.line((p.x)+5,(p.y)+14,(p.x)+6,(p.y)+14,1)
    oled.line((p.x)+5,(p.y)+15,(p.x)+6,(p.y)+15,1)
    oled.line((p.x)+5,(p.y)+10,(p.x)+5,(p.y)+8,1)
    oled.line((p.x)+5,(p.y)+8,(p.x)+8,(p.y)+6,1)
    oled.line((p.x)+8,(p.y)+6,(p.x)+9,(p.y)+2,1)
    oled.line((p.x)+8,(p.y)+1,(p.x)+4,(p.y)+1,1)

def amp(p):
    #&
    oled.line((p.x)+4,(p.y)+7,(p.x)+2,(p.y)+5,1)
    oled.line((p.x)+2,(p.y)+5,(p.x)+2,(p.y)+3,1)
    oled.line((p.x)+2,(p.y)+3,(p.x)+3,(p.y)+2,1)
    oled.line((p.x)+3,(p.y)+2,(p.x)+4,(p.y)+1,1)
    oled.line((p.x)+4,(p.y)+1,(p.x)+6,(p.y)+1,1)
    oled.line((p.x)+6,(p.y)+1,(p.x)+7,(p.y)+2,1)
    oled.line((p.x)+7,(p.y)+2,(p.x)+8,(p.y)+3,1)
    oled.line((p.x)+8,(p.y)+3,(p.x)+8,(p.y)+4,1)
    oled.line((p.x)+8,(p.y)+4,(p.x)+6,(p.y)+6,1)
    oled.line((p.x)+6,(p.y)+6,(p.x)+1,(p.y)+10,1)
    oled.line((p.x)+1,(p.y)+10,(p.x)+1,(p.y)+13,1)
    oled.line((p.x)+1,(p.y)+13,(p.x)+3,(p.y)+15,1)
    oled.line((p.x)+3,(p.y)+15,(p.x)+6,(p.y)+15,1)
    oled.line((p.x)+6,(p.y)+15,(p.x)+9,(p.y)+9,1)
    oled.line((p.x)+4,(p.y)+8,(p.x)+10,(p.y)+15,1)

def zero(p):
    oled.line((p.x)+10,(p.y)+5,(p.x)+8,(p.y)+1,1)
    oled.line((p.x)+8,(p.y)+1,(p.x)+4,(p.y)+1,1)
    oled.line((p.x)+4,(p.y)+1,(p.x)+2,(p.y)+3,1)
    oled.line((p.x)+2,(p.y)+3,(p.x)+1,(p.y)+7,1)
    oled.line((p.x)+1,(p.y)+7,(p.x)+1,(p.y)+12,1)
    oled.line((p.x)+1,(p.y)+12,(p.x)+4,(p.y)+15,1)
    oled.line((p.x)+4,(p.y)+15,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+10,(p.y)+12,1)
    oled.line((p.x)+10,(p.y)+12,(p.x)+10,(p.y)+5,1)
    oled.line((p.x)+9,(p.y)+4,(p.x)+2,(p.y)+12,1)

def one(p):
    oled.line((p.x)+5,(p.y)+15,(p.x)+5,(p.y)+1,1)
    oled.line((p.x)+5,(p.y)+1,(p.x)+2,(p.y)+3,1)

def two(p):
    oled.line((p.x)+1,(p.y)+3,(p.x)+2,(p.y)+1,1)
    oled.line((p.x)+2,(p.y)+1,(p.x)+7,(p.y)+1,1)
    oled.line((p.x)+7,(p.y)+1,(p.x)+9,(p.y)+3,1)
    oled.line((p.x)+9,(p.y)+3,(p.x)+9,(p.y)+6,1)
    oled.line((p.x)+9,(p.y)+6,(p.x)+2,(p.y)+13,1)
    oled.line((p.x)+2,(p.y)+13,(p.x)+1,(p.y)+15,1)
    oled.line((p.x)+1,(p.y)+15,(p.x)+10,(p.y)+15,1)

def three(p):
    oled.line((p.x)+1,(p.y)+3,(p.x)+2,(p.y)+1,1)
    oled.line((p.x)+2,(p.y)+1,(p.x)+7,(p.y)+1,1)
    oled.line((p.x)+7,(p.y)+1,(p.x)+9,(p.y)+3,1)
    oled.line((p.x)+9,(p.y)+3,(p.x)+9,(p.y)+5,1)
    oled.line((p.x)+9,(p.y)+5,(p.x)+7,(p.y)+7,1)
    oled.line((p.x)+7,(p.y)+7,(p.x)+4,(p.y)+7,1)
    oled.line((p.x)+7,(p.y)+8,(p.x)+9,(p.y)+9,1)
    oled.line((p.x)+9,(p.y)+9,(p.x)+9,(p.y)+12,1)
    oled.line((p.x)+9,(p.y)+12,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+3,(p.y)+15,1)
    oled.line((p.x)+3,(p.y)+15,(p.x)+1,(p.y)+13,1)

def four(p):
    oled.line((p.x)+8,(p.y)+1,(p.x)+8,(p.y)+15,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+1,(p.y)+7,1)
    oled.line((p.x)+1,(p.y)+7,(p.x)+9,(p.y)+7,1)

def five(p):
    oled.line((p.x)+9,(p.y)+1,(p.x)+1,(p.y)+1,1)
    oled.line((p.x)+1,(p.y)+1,(p.x)+1,(p.y)+7,1)
    oled.line((p.x)+7,(p.y)+7,(p.x)+1,(p.y)+7,1)
    oled.line((p.x)+7,(p.y)+8,(p.x)+9,(p.y)+9,1)
    oled.line((p.x)+9,(p.y)+9,(p.x)+9,(p.y)+12,1)
    oled.line((p.x)+9,(p.y)+12,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+3,(p.y)+15,1)
    oled.line((p.x)+3,(p.y)+15,(p.x)+1,(p.y)+13,1)

def six(p):
    oled.line((p.x)+10,(p.y)+3,(p.x)+8,(p.y)+1,1)
    oled.line((p.x)+8,(p.y)+1,(p.x)+4,(p.y)+1,1)
    oled.line((p.x)+4,(p.y)+1,(p.x)+2,(p.y)+3,1)
    oled.line((p.x)+2,(p.y)+3,(p.x)+1,(p.y)+7,1)
    oled.line((p.x)+1,(p.y)+7,(p.x)+1,(p.y)+12,1)
    oled.line((p.x)+1,(p.y)+12,(p.x)+4,(p.y)+15,1)
    oled.line((p.x)+4,(p.y)+15,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+10,(p.y)+13,1)
    oled.line((p.x)+10,(p.y)+13,(p.x)+10,(p.y)+9,1)
    oled.line((p.x)+10,(p.y)+9,(p.x)+8,(p.y)+7,1)
    oled.line((p.x)+8,(p.y)+7,(p.x)+4,(p.y)+7,1)
    oled.line((p.x)+4,(p.y)+7,(p.x)+2,(p.y)+9,1)

def seven(p):
    oled.line((p.x)+1,(p.y)+1,(p.x)+10,(p.y)+1,1)
    oled.line((p.x)+10,(p.y)+1,(p.x)+3,(p.y)+15,1)

def eight(p):
    oled.line((p.x)+4,(p.y)+7,(p.x)+2,(p.y)+5,1)
    oled.line((p.x)+2,(p.y)+5,(p.x)+2,(p.y)+3,1)
    oled.line((p.x)+2,(p.y)+3,(p.x)+3,(p.y)+2,1)
    oled.line((p.x)+3,(p.y)+2,(p.x)+4,(p.y)+1,1)
    oled.line((p.x)+4,(p.y)+1,(p.x)+6,(p.y)+1,1)
    oled.line((p.x)+6,(p.y)+1,(p.x)+7,(p.y)+2,1)
    oled.line((p.x)+7,(p.y)+2,(p.x)+8,(p.y)+3,1)
    oled.line((p.x)+8,(p.y)+3,(p.x)+8,(p.y)+5,1)
    oled.line((p.x)+8,(p.y)+5,(p.x)+6,(p.y)+7,1)
    oled.line((p.x)+1,(p.y)+10,(p.x)+1,(p.y)+13,1)
    oled.line((p.x)+1,(p.y)+13,(p.x)+3,(p.y)+15,1)
    oled.line((p.x)+3,(p.y)+15,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+9,(p.y)+13,1)
    oled.line((p.x)+9,(p.y)+13,(p.x)+9,(p.y)+10,1)
    oled.line((p.x)+9,(p.y)+10,(p.x)+6,(p.y)+7,1)
    oled.line((p.x)+6,(p.y)+7,(p.x)+4,(p.y)+7,1)
    oled.line((p.x)+4,(p.y)+7,(p.x)+2,(p.y)+9,1)

def nine(p):
    oled.line((p.x)+10,(p.y)+6,(p.x)+8,(p.y)+8,1)
    oled.line((p.x)+8,(p.y)+8,(p.x)+3,(p.y)+8,1)
    oled.line((p.x)+3,(p.y)+8,(p.x)+1,(p.y)+5,1)
    oled.line((p.x)+1,(p.y)+5,(p.x)+1,(p.y)+3,1)
    oled.line((p.x)+1,(p.y)+3,(p.x)+3,(p.y)+1,1)
    oled.line((p.x)+3,(p.y)+1,(p.x)+8,(p.y)+1,1)
    oled.line((p.x)+8,(p.y)+1,(p.x)+10,(p.y)+3,1)
    oled.line((p.x)+10,(p.y)+3,(p.x)+10,(p.y)+10,1)
    oled.line((p.x)+10,(p.y)+10,(p.x)+9,(p.y)+13,1)
    oled.line((p.x)+9,(p.y)+13,(p.x)+7,(p.y)+15,1)
    oled.line((p.x)+7,(p.y)+15,(p.x)+3,(p.y)+15,1)
    oled.line((p.x)+3,(p.y)+15,(p.x)+1,(p.y)+13,1)

def space(p):
    pass

#positon object 

class Pos:
    def __init__(self, x, y):
        self.x=x
        self.y=y
       
#define position x and y   
p0=Pos(0,0)
p1=Pos(15,0)
p2=Pos(30,0)
p3=Pos(45,0)
p4=Pos(60,0)
p5=Pos(75,0)
p6=Pos(90,0)
p7=Pos(105,0)
p8=Pos(0,22)
p9=Pos(15,22)
p10=Pos(30,22)
p11=Pos(45,22)
p12=Pos(60,22)
p13=Pos(75,22)
p14=Pos(90,22)
p15=Pos(105,22)
p16=Pos(0,44)
p17=Pos(15,44)
p18=Pos(30,44)
p19=Pos(45,44)
p20=Pos(60,44)
p21=Pos(75,44)
p22=Pos(90,44)
p23=Pos(105,44)

line1Array=[p0,p1,p2,p3,p4,p5,p6,p7]
line2Array=[p8,p9,p10,p11,p12,p13,p14,p15]
line3Array=[p16,p17,p18,p19,p20,p21,p22,p23]
displayArray=[p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19,p20,p21,p22,p23]



def display(text, posArray):
    for i in range (len(text)):
        if text[i]=="A" or text[i]=="a":
            A(posArray[i])
        if text[i]=="B" or text[i]=="b":
            B(posArray[i])
        if text[i]=="C" or text[i]=="c":
            C(posArray[i])
        if text[i]=="D" or text[i]=="d":
            D(posArray[i])
        if text[i]=="E" or text[i]=="e":
            E(posArray[i])
        if text[i]=="F" or text[i]=="f":
            F(posArray[i])
        if text[i]=="G" or text[i]=="g":
            G(posArray[i])
        if text[i]=="H" or text[i]=="h":
            H(posArray[i])
        if text[i]=="I" or text[i]=="i":
            I(posArray[i])
        if text[i]=="J" or text[i]=="j":
            J(posArray[i])
        if text[i]=="K" or text[i]=="k":
            K(posArray[i])
        if text[i]=="L" or text[i]=="l":
            L(posArray[i])
        if text[i]=="M" or text[i]=="m":
            M(posArray[i])
        if text[i]=="N" or text[i]=="n":
            N(posArray[i])
        if text[i]=="O" or text[i]=="o":
            O(posArray[i])
        if text[i]=="P" or text[i]=="p":
            P(posArray[i])
        if text[i]=="Q" or text[i]=="q":
            Q(posArray[i])
        if text[i]=="R" or text[i]=="r":
            R(posArray[i])
        if text[i]=="S" or text[i]=="s":
            S(posArray[i])
        if text[i]=="T" or text[i]=="t":
            T(posArray[i])
        if text[i]=="U" or text[i]=="u":
            U(posArray[i])
        if text[i]=="V" or text[i]=="v":
            V(posArray[i])
        if text[i]=="W" or text[i]=="w":
            W(posArray[i])
        if text[i]=="X" or text[i]=="x":
            X(posArray[i])
        if text[i]=="Y" or text[i]=="y":
            Y(posArray[i])
        if text[i]=="Z" or text[i]=="z":
            Z(posArray[i])
        if text[i]=="0":
            zero(posArray[i])
        if text[i]=="1":
            one(posArray[i])
        if text[i]=="2":
            two(posArray[i])
        if text[i]=="3":
            three(posArray[i])
        if text[i]=="4":
            four(posArray[i])
        if text[i]=="5":
            five(posArray[i])
        if text[i]=="6":
            six(posArray[i])
        if text[i]=="7":
            seven(posArray[i])
        if text[i]=="8":
            eight(posArray[i])
        if text[i]=="9":
            nine(posArray[i])
        if text[i]==".":
            period(posArray[i])
        if text[i]=="!":
            exclam(posArray[i])
        if text[i]=="?":
            question(posArray[i])
        if text[i]=="/":
            slash(posArray[i])
        if text[i]==":":
            colon(posArray[i])
        if text[i]==",":
            comma(posArray[i])
        if text[i]=="&":
            amp(posArray[i])
        if text[i]=="+":
            plus(posArray[i])
        if text[i]=="-":
            minus(posArray[i])
        if text[i]=="=":
            equal(posArray[i])
        if text[i]==" ":
            space(posArray[i])

def setOLED(ol):
    global oled
    oled = ol

def line1(line1text):
    display(line1text, line1Array)

def line2(line2text):
    display(line2text, line2Array)

def line3(line3text):
    display(line3text, line3Array)